@@ -17,7 +17,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(format_pretty);
 
-our $VERSION = '0.26'; # VERSION
+our $VERSION = '0.27'; # VERSION
 
 sub content_type { "text/plain" }
 
@@ -234,7 +234,7 @@ sub _format_list {
     if ($self->{opts}{interactive}) {
 
         require List::Util;
-        require Term::Size::ReadKey;
+        require Term::Size;
         require POSIX;
 
         # format list as as columns (a la 'ls' output)
@@ -242,7 +242,7 @@ sub _format_list {
         my @rows = map { $self->_format_cell($_) } @$data;
 
         my $maxwidth = List::Util::max(map { length } @rows) // 0;
-        my ($termcols, $termrows) = Term::Size::ReadKey::chars();
+        my ($termcols, $termrows) = Term::Size::chars();
         $termcols //= 0; # if undetected
         my $numcols = 1;
         if ($maxwidth) {
@@ -453,7 +453,7 @@ Data::Format::Pretty::Console - Pretty-print data structure for console output
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 SYNOPSIS
 
